==> hoteldruid-mod-sv_2.1.2-1.tar.gz: sv/gestione_utenti.php <==
<?php

switch ($messaggio) {

case "Il <b>nome</b> dell'utente":  		$messaggio = "Anv&auml;ndarens <b>namn</b>"; break;
case "verrà cambiato da":  			$messaggio = "kommer &auml;ndras fr&aring;n"; break;
case "a":  					$messaggio = "till"; break;
case "Il <b>login</b> dell'utente":  		$messaggio = "<b>Inloggningsnamnet</b> f&ouml;r anv&auml;ndaren"; break;
case "password conservata in chiaro":  		$messaggio = "l&ouml;senordet sparas i vanlig text"; break;
case "password conservata criptata con md5":  	$messaggio = "l&ouml;senordet sparas krypterat med md5"; break;
case "password conservata criptata con mcrypt":	$messaggio = "l&ouml;senordet sparas krypterat med mcrypt"; break;
case "password conservata criptata con mhash":	$messaggio = "l&ouml;senordet sparas krypterat med mhash"; break;
case "disabilitato":  				$messaggio = "avaktiverat"; break;
case "Inserisci una nuova password":  		$messaggio = "Ange ett nytt l&ouml;senord"; break;
case "Ripeti la password":  			$messaggio = "Upprepa l&ouml;senordet"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Det finns redan</div> en anv&auml;ndare med namnet"; break;
case "Nuova password dell'utente":  		$messaggio = "Nytt l&ouml;senord f&ouml;r anv&auml;ndaren"; break;
case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">inte</div> korrekt angivet"; break;
case "<b>Non</b> è stato effettuato nessun cambiamento":	$messaggio = "<b>Inga</b> &auml;ndringar har genomf&ouml;rts"; break;
case "Esiste già un utente chiamato":  		$messaggio = "Det finns redan en anv&auml;ndare vid namn"; break;
case "Le nuove password non coincidono":  	$messaggio = "Nya l&ouml;senord st&auml;mmer inte &ouml;verens"; break;
case "Inserisci una nuova password per l'utente":	$messaggio = "Age ett nytt l&ouml;senord f&ouml;r anv&auml;ndaren"; break;
case "Nuova password":  			$messaggio = "Nytt l&ouml;senord"; break;
case "N°":  					$messaggio = "nr"; break;
case "nome":  					$messaggio = "namn"; break;
case "login":  					$messaggio = "inloggningsnamn"; break;
case "modifica":  				$messaggio = "&auml;ndra"; break;
case "password criptata con md5":  		$messaggio = "l&ouml;senord krypterat med md5"; break;
case "password criptata con mcrypt":  		$messaggio = "l&ouml;senord krypterat med mcrypt"; break;
case "password criptata con mhash":  		$messaggio = "l&ouml;senord krypterat med mhash"; break;
case "password":  				$messaggio = "l&ouml;senord"; break;
case "privilegi":  				$messaggio = "privilegier"; break;
case "Amministratore":  			$messaggio = "Administrat&ouml;r"; break;
case "Abilitare per usare altri utenti":  	$messaggio = "Till&aring;t anv&auml;ndning av andra anv&auml;ndare"; break;
case "Modifica gli utenti":  			$messaggio = "&Auml;ndra anv&auml;ndare"; break;
case "Aggiungi":  				$messaggio = "L&auml;gg till"; break;
case "un nuovo utente chiamato":  		$messaggio = "en ny anv&auml;ndare vid namn"; break;
case "Importa i privilegi":  			$messaggio = "Importera privilegier"; break;
case "dell'utente":  				$messaggio = "f&ouml;r anv&auml;ndaren"; break;
case "del gruppo":  				$messaggio = "f&ouml;r gruppen"; break;
case "dall'utente":  				$messaggio = "fr&aring;n anv&auml;ndaren"; break;
case "Privilegi importati":  			$messaggio = "Privilegier importerade"; break;
case "Importa":  				$messaggio = "Importera"; break;
case "gruppi":  				$messaggio = "grupper"; break;
case "Aggiornati i gruppi dell'utente":  	$messaggio = "Uppdaterade grupper f&ouml;r anv&auml;ndaren"; break;
case "Gruppi dell'utente":  			$messaggio = "Grupper f&ouml;r anv&auml;ndaren"; break;
case "Nuovo gruppo":  				$messaggio = "Ny grupp"; break;
case "Esiste già un gruppo chiamato":  		$messaggio = "Det finns redan en grupp vid namn"; break;
case "Modifica":  				$messaggio = "&Auml;ndra"; break;
case "cancella":  				$messaggio = "ta bort"; break;
case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <b style=\"font-weight: normal; color: red;\">ta bort</b> anv&auml;ndaren"; break;
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "NEJ"; break;
case "Gestione degli utenti di hoteldruid":	$messaggio = "HotelDruid users management"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_2.2.3-1.tar.gz: sv/gestione_utenti.php <==
<?php

switch ($messaggio) {

case "Il <b>nome</b> dell'utente":  		$messaggio = "Anv&auml;ndarens <b>namn</b>"; break;
case "verrà cambiato da":  			$messaggio = "kommer &auml;ndras fr&aring;n"; break;
case "a":  					$messaggio = "till"; break;
case "Il <b>login</b> dell'utente":  		$messaggio = "<b>Inloggningsnamnet</b> f&ouml;r anv&auml;ndaren"; break;
case "password conservata in chiaro":  		$messaggio = "l&ouml;senordet sparas i vanlig text"; break;
case "password conservata criptata con md5":  	$messaggio = "l&ouml;senordet sparas krypterat med md5"; break;
case "password conservata criptata con mcrypt":	$messaggio = "l&ouml;senordet sparas krypterat med mcrypt"; break;
case "password conservata criptata con mhash":	$messaggio = "l&ouml;senordet sparas krypterat med mhash"; break;
case "disabilitato":  				$messaggio = "avaktiverat"; break;
case "Inserisci una nuova password":  		$messaggio = "Ange ett nytt l&ouml;senord"; break;
case "Ripeti la password":  			$messaggio = "Upprepa l&ouml;senordet"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Det finns redan</div> en anv&auml;ndare med namnet"; break;
case "Nuova password dell'utente":  		$messaggio = "Nytt l&ouml;senord f&ouml;r anv&auml;ndaren"; break;
case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">inte</div> korrekt angivet"; break;
case "<b>Non</b> è stato effettuato nessun cambiamento":	$messaggio = "<b>Inga</b> &auml;ndringar har genomf&ouml;rts"; break;
case "Esiste già un utente chiamato":  		$messaggio = "Det finns redan en anv&auml;ndare vid namn"; break;
case "Le nuove password non coincidono":  	$messaggio = "Nya l&ouml;senord st&auml;mmer inte &ouml;verens"; break;
case "Inserisci una nuova password per l'utente":	$messaggio = "Age ett nytt l&ouml;senord f&ouml;r anv&auml;ndaren"; break;
case "Nuova password":  			$messaggio = "Nytt l&ouml;senord"; break;
case "N°":  					$messaggio = "nr"; break;
case "nome":  					$messaggio = "namn"; break;
case "login":  					$messaggio = "inloggningsnamn"; break;
case "modifica":  				$messaggio = "&auml;ndra"; break;
case "password criptata con md5":  		$messaggio = "l&ouml;senord krypterat med md5"; break;
case "password criptata con mcrypt":  		$messaggio = "l&ouml;senord krypterat med mcrypt"; break;
case "password criptata con mhash":  		$messaggio = "l&ouml;senord krypterat med mhash"; break;
case "password":  				$messaggio = "l&ouml;senord"; break;
case "privilegi":  				$messaggio = "privilegier"; break;
case "Amministratore":  			$messaggio = "Administrat&ouml;r"; break;
case "Abilitare per usare altri utenti":  	$messaggio = "Till&aring;t anv&auml;ndning av andra anv&auml;ndare"; break;
case "Modifica gli utenti":  			$messaggio = "&Auml;ndra anv&auml;ndare"; break;
case "Aggiungi":  				$messaggio = "L&auml;gg till"; break;
case "un nuovo utente chiamato":  		$messaggio = "en ny anv&auml;ndare vid namn"; break;
case "dell'utente":  				$messaggio = "f&ouml;r anv&auml;ndaren"; break;
case "del gruppo":  				$messaggio = "f&ouml;r gruppen"; break;
case "dall'utente":  				$messaggio = "fr&aring;n anv&auml;ndaren"; break;
case "Privilegi importati":  			$messaggio = "Privilegier importerade"; break;
case "Importa":  				$messaggio = "Importera"; break;
case "gruppi":  				$messaggio = "grupper"; break;
case "Aggiornati i gruppi dell'utente":  	$messaggio = "Uppdaterade grupper f&ouml;r anv&auml;ndaren"; break;
case "Gruppi dell'utente":  			$messaggio = "Grupper f&ouml;r anv&auml;ndaren"; break;
case "Nuovo gruppo":  				$messaggio = "Ny grupp"; break;
case "Esiste già un gruppo chiamato":  		$messaggio = "Det finns redan en grupp vid namn"; break;
case "Modifica":  				$messaggio = "&Auml;ndra"; break;
case "cancella":  				$messaggio = "ta bort"; break;
case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <b style=\"font-weight: normal; color: red;\">ta bort</b> anv&auml;ndaren"; break;
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "NEJ"; break;
case "Gestione degli utenti di hoteldruid":	$messaggio = "HotelDruid users management"; break;
case "privilegi e personalizzazioni":  		$messaggio = "privileges and customizations"; break;
case "solo i privilegi":  			$messaggio = "only privileges"; break;
case "solo le personalizzazioni":  		$messaggio = "only customizations"; break;
case "Personalizzazioni importate":  		$messaggio = "Customizations imported"; break;
case "privilegi, personalizzazioni e gruppi":	$messaggio = "privileges, customizations and groups"; break;
case "privilegi e gruppi":  			$messaggio = "privileges and groups"; break;
case "personalizzazioni e gruppi":  		$messaggio = "customizations and groups"; break;
case "solo i gruppi":  				$messaggio = "only groups"; break;
case "Gruppi importati":  			$messaggio = "Groups imported"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
